# Embedding-based Bert Re-Ranker


Bert model to rank answers for a given question.

## Instructions

Enable flake8 check before commit:
(run from the root of the repository)

    cd .git/hooks/ && ln -s ../../config/hooks/pre-commit . && cd -